==========
Public API
==========

.. seealso:: Check out :ref:`examples` derived from real and fully tested source code.

.. py:module:: dotty_dict.dotty_dict

.. autofunction:: dotty

.. autoclass:: Dotty
   :member-order: alphabetical
   :members:

   .. method:: clear()

      Removes all elements from dotty dict.

   .. method:: items()

      Returns generator of dotty dict's (key, value) tuple pairs.

   .. method:: keys()

      Returns generator of dotty dict's keys.

   .. method:: values()

      Returns generator of dotty dict's values.

   .. method:: update(dict2)

      Adds dictionary dict2's key-values pairs to dotty dict.
